[PATCH 70/74] staging: rtl8723au: Declare rtw_site_survey() static

Jes.Sorensen at redhat.com Jes.Sorensen at redhat.com
Wed May 21 07:38:34 UTC 2014


From: Jes Sorensen <Jes.Sorensen at redhat.com>

Signed-off-by: Jes Sorensen <Jes.Sorensen at redhat.com>
---
 drivers/staging/rtl8723au/core/rtw_mlme_ext.c    | 8 ++++----
 drivers/staging/rtl8723au/include/rtw_mlme_ext.h | 1 -
 2 files changed, 4 insertions(+), 5 deletions(-)

diff --git a/drivers/staging/rtl8723au/include/rtw_mlme_ext.h b/drivers/staging/rtl8723au/include/rtw_mlme_ext.h
index afbd807..0f75730 100644
--- a/drivers/staging/rtl8723au/include/rtw_mlme_ext.h
+++ b/drivers/staging/rtl8723au/include/rtw_mlme_ext.h
@@ -495,7 +495,6 @@ void flush_all_cam_entry23a(struct rtw_adapter *padapter);
 
 bool IsLegal5GChannel(struct rtw_adapter *Adapter, u8 channel);
 
-void site_survey23a(struct rtw_adapter *padapter);
 int collect_bss_info23a(struct rtw_adapter *padapter,
 			struct recv_frame *precv_frame,
 			struct wlan_bssid_ex *bssid);
diff --git a/drivers/staging/rtl8723au/core/rtw_mlme_ext.c b/drivers/staging/rtl8723au/core/rtw_mlme_ext.c
index 58ff635..1a36e64 100644
--- a/drivers/staging/rtl8723au/core/rtw_mlme_ext.c
+++ b/drivers/staging/rtl8723au/core/rtw_mlme_ext.c
@@ -4384,7 +4384,7 @@ bool IsLegal5GChannel(struct rtw_adapter *Adapter, u8 channel)
 	return false;
 }
 
-void site_survey23a(struct rtw_adapter *padapter)
+static void rtw_site_survey(struct rtw_adapter *padapter)
 {
 	unsigned char survey_channel = 0;
 	enum rt_scan_type ScanType = SCAN_PASSIVE;
@@ -4401,7 +4401,7 @@ void site_survey23a(struct rtw_adapter *padapter)
 	}
 
 	if (survey_channel != 0) {
 		/* PAUSE 4-AC Queue when site_survey23a */
 		if (pmlmeext->sitesurvey_res.channel_idx == 0)
 			set_channel_bwmode23a(padapter, survey_channel,
 					      HAL_PRIME_CHNL_OFFSET_DONT_CARE,
@@ -4440,7 +4440,7 @@ void site_survey23a(struct rtw_adapter *padapter)
 				      pmlmeext->cur_ch_offset,
 				      pmlmeext->cur_bwmode);
 
 		/* flush 4-AC Queue after site_survey23a */
 		/* val8 = 0; */
 
 		/* config MSR */
@@ -6213,7 +6213,7 @@ int sitesurvey_cmd_hdl23a(struct rtw_adapter *padapter, const u8 *pbuf)
 		pmlmeext->sitesurvey_res.state = SCAN_PROCESS;
 	}
 
-	site_survey23a(padapter);
+	rtw_site_survey(padapter);
 
 	return H2C_SUCCESS;
 }
@@ -4401,7 +4401,7 @@ void site_survey23a(struct rtw_adapter *padapter)
 
 	if (survey_channel != 0) {
-		/* PAUSE 4-AC Queue when site_survey23a */
+		/* PAUSE 4-AC Queue when site_survey */
 		if (pmlmeext->sitesurvey_res.channel_idx == 0)
 			set_channel_bwmode23a(padapter, survey_channel,
@@ -4440,7 +4440,7 @@ void site_survey23a(struct rtw_adapter *padapter)
 				      pmlmeext->cur_bwmode);
 
-		/* flush 4-AC Queue after site_survey23a */
+		/* flush 4-AC Queue after rtw_site_survey */
 		/* val8 = 0; */
 
-- 
1.9.0



More information about the devel mailing list